<?php

/*
 * EAcceleratorCachePlugin.class.php - configuring eaccelerator as cache for
 *                                     Stud.IP
 *
 * Copyright (C) 2007 - Marcus Lunzenauer <mlunzena@uos.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */


/**
 * @author    mlunzena
 * @copyright (c) Authors
 * @version   $Id: EAcceleratorCachePlugin.class.php 400 2007-09-07 13:55:24Z mlunzena $
 */

class EAcceleratorCachePlugin extends AbstractStudIPAdministrationPlugin {


  const CACHE_CLASS = 'EAcceleratorCache';
  const CACHE_FILE  = 'eaccelerator_cache.php';
  const DOMAIN      = 'EAcceleratorCachePlugin';
  const TEST_METHOD = 'eaccelerator_put';
  const EXTENSION   = 'EAccelerator';


  function __construct() {

    parent::AbstractStudIPAdministrationPlugin();

    $this->setPluginiconname("img/plugin.png");

    # navigation
    $navigation = new PluginNavigation();
    $navigation->setDisplayname(self::CACHE_CLASS . '-' .
                                dgettext(self::DOMAIN, 'Konfiguration'));
    $this->setNavigation($navigation);
  }


  function getPluginname() {
    return self::CACHE_CLASS . '-' . dgettext(self::DOMAIN, 'Konfiguration');
  }


  function setActivated($value = FALSE, $requestedbyuser = FALSE){
    parent::setActivated($value, $requestedbyuser);

    if (FALSE === $value && $this->cache_enabled()) {
      StudipCacheFactory::unconfigure();
    }
  }


  function actionShow() {

    $factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates');

    $domain = self::DOMAIN;
    $extension = self::EXTENSION;

    # is the extension available?
    if (!$this->extension_available()) {
      echo $factory->render('not_installed', compact('domain', 'extension'));
      return;
    }


    $message = array();

    # form were submitted
    if ('POST' == $_SERVER['REQUEST_METHOD']) {

      # activate cache
      if (isset($_POST['activate'])) {
        StudipCacheFactory::configure(dirname(__FILE__) . '/' .
                                      self::CACHE_FILE,
                                      self::CACHE_CLASS,
                                      array());
        $message[] = dgettext(self::DOMAIN, 'Cache fr Stud.IP aktiviert.');
      }

      # deactivate cache
      else if (isset($_POST['deactivate'])) {
        StudipCacheFactory::unconfigure();
        $message[] = dgettext(self::DOMAIN,
                              'Cache fr Stud.IP deaktiviert.');
      }
    }

    $cache = StudipCacheFactory::getCache();
    $current_cache_class = get_class($cache);
    $enabled = $this->cache_enabled();


    echo $factory->render('form',
      compact('message', 'enabled', 'current_cache_class', 'domain', 'extension'));
  }


  private function extension_available() {
    return function_exists(self::TEST_METHOD);
  }


  private function cache_enabled() {
    $cache = StudipCacheFactory::getCache();
    return get_class($cache) == self::CACHE_CLASS;
  }
}

