<?php

/*
 * Copyright (C) 2007 - Marcus Lunzenauer <mlunzena@uos.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */


/**
 * Cache implementation using eaccelerator.
 *
 * @package     studip
 * @subpackage  cache
 *
 * @author    mlunzena
 * @copyright (c) Authors
 * @version   $Id: eaccelerator_cache.php 400 2007-09-07 13:55:24Z mlunzena $
 */

class EAcceleratorCache implements StudipCache {


  function __construct() {
    if (!function_exists('eaccelerator_put')) {
      throw new Exception('EAccelerator extension missing.');
    }
  }


  /**
   * Expire item from the cache.
   *
   * Example:
   *
   *   # expires foo
   *   $cache->expire('foo');
   *
   * @param   string  a single key.
   *
   * @returns void
   *
   */
  function expire($arg) {
    eaccelerator_rm($arg);
  }


  /**
   * Retrieve item from the server.
   *
   * Example:
   *
   *   # reads foo
   *   $foo = $cache->reads('foo');
   *
   * @param   string  a single key
   *
   * @returns mixed  the previously stored data if an item with such a key
   *                 exists on the server or FALSE on failure.
   */
  function read($arg) {
    $result = eaccelerator_get($arg);
    return isset($result) ? $result : FALSE;
  }


  /**
   * Store data at the server.
   *
   * @param string   the item's key.
   * @param string   the item's content.
   * @param int      the item's expiry time in seconds. Defaults to 12h.
   *
   * @returns mixed  returns TRUE on success or FALSE on failure.
   *
   */
  function write($name, $content, $expire = 43200) {
    return eaccelerator_put($name, $content, $expire);
  }
}
